==> exonmap_1.0.07.tar.gz: exonmap/R/splanova.R <==
###############################################################################
# splanova - MIDAS-like splicing search using anova
# MO, March 2007
###############################################################################
setClass("Splanova",representation(fval="list",sig="list"))

setGeneric("fval", function(object) standardGeneric("fval"))
setMethod("fval","Splanova",function(object) object@fval)

setGeneric("sig", function(object) standardGeneric("sig"))
setMethod("sig","Splanova",function(object) object@sig)

splanova <- function(x,genesin, group,base, thr=0.05, probes.min=4, exonic=TRUE, debug=0) {
  fv <- as.list(NULL)
  sig <- as.list(NULL)
  if(class(x) != "ExpressionSet") {stop("'x' must be an ExpressionSet object."); }

  for (g in genesin)
  { 
    if (debug>2) cat ("Processing ",g,"\n") 
    gm <- .gene.midas(x, g, group, base, thr, probes.min, exonic, debug)
    fv[[g]] <- gm$out
    sig[[g]] <- gm$desc
  }

  return(new("Splanova",fval=fv,sig=sig))
}
###############################################################################
.midas.pset.frame <- function(x,pset,pD, group, base, debug=0)
{
pD <- pD[,group]
trs <- unique(as.character(pD))
num.trs <- length(trs)
in.vec <- x[pset,]
num.samp <- length(in.vec)

out <- matrix(nrow=num.samp, ncol=num.trs+1)
out[,] <- 0
out <- data.frame(out)
colnames(out) <- c(trs,"expval")
rownames(out) <- names(in.vec)

for (i in 1:num.samp)
   {  
      if (pD[i]!=base)
      {
      jj <- which (trs==pD[i])
      out[i,jj] <- 1
      }
      out[i,"expval"] <- in.vec[i]
   }

out
}


.gene.midas <- function(x, gene, group, base, thr=0.05,  probes.min=4, exonic=TRUE, debug=0)
{
   ee <- exprs(x)
   pD <- pData(x)
   if (length(unique(pD[,group]))<=2) stop("Not enough \"",group,"\" variable levels in pData!")
   psets <- gene.to.probeset(gene, probes.min=probes.min, debug=debug)
   if (exonic) psets <- select.probewise(psets, filter="exonic", debug=debug)
   print(psets)
   out <- NULL
   out.desc <- NULL
   oo <- NULL

   #normalization
   ee <- ee[psets, ]
   ee <- apply (ee, 2, function(x) x/mean(x)) 

   for (p in psets)
   {
      pf <- .midas.pset.frame(ee,  p, pD,  group, base, debug=debug)
      print(pf)
      modelfrm <-  "expval ~ "
      for (i in 1:(length(colnames(pf))-2)) modelfrm <- paste(modelfrm, colnames(pf)[i],"+", sep="")
      modelfrm <- paste(modelfrm, colnames(pf)[length(colnames(pf))-1], sep="")
      if (debug>6) cat("Model",modelfrm,"\n")
      tmp.mod <- lm(as.formula(modelfrm), data=pf)
      aa <- anova(tmp.mod)
      trtr <- rownames(aa)[which (aa["Pr(>F)"]<thr)]
      if (length(trtr)>0)
      {
        desc <- paste (p, trtr, sep="")
        if (debug>3) cat ("Interesting splicing in :",desc, "\n")
        out.desc <- c(out.desc, desc)
      }
      out <- rbind(out, aa[1:((dim(aa)[1]-1)),"Pr(>F)"])
   }
if (length(psets)>0)
{ 
rownames(out) <- psets
colnames(out) <- colnames(pf)[2:(length(colnames(pf))-1)]
}
else warning("Gene ",gene," has no well-behaved exonic probesets!")
out
oo$out <- out
oo$desc <- out.desc
oo
}

==> exonmap_1.4.3.tar.gz: exonmap/R/splanova.R <==
###############################################################################
# splanova - MIDAS-like splicing search using anova
# MO, March 2007
###############################################################################
setClass("Splanova",representation(fval="list",sig="list"))

setGeneric("fval", function(object) standardGeneric("fval"))
setMethod("fval","Splanova",function(object) object@fval)

setGeneric("sig", function(object) standardGeneric("sig"))
setMethod("sig","Splanova",function(object) object@sig)

splanova <- function(x,genesin, group,base, thr=0.05, probes.min=4, exonic=TRUE) {
  fv <- as.list(NULL)
  sig <- as.list(NULL)
  if(class(x) != "ExpressionSet") {stop("'x' must be an ExpressionSet object."); }

  for (g in genesin)
  { 
    gm <- .gene.midas(x, g, group, base, thr, probes.min, exonic)
    fv[[g]] <- gm$out
    sig[[g]] <- gm$desc
  }

  return(new("Splanova",fval=fv,sig=sig))
}
###############################################################################
.midas.pset.frame <- function(x,pset,pD, group, base)
{
pD <- pD[,group]
trs <- unique(as.character(pD))
num.trs <- length(trs)
in.vec <- x[pset,]
num.samp <- length(in.vec)

out <- matrix(nrow=num.samp, ncol=num.trs+1)
out[,] <- 0
out <- data.frame(out)
colnames(out) <- c(trs,"expval")
rownames(out) <- names(in.vec)

for (i in 1:num.samp)
   {  
      if (pD[i]!=base)
      {
      jj <- which (trs==pD[i])
      out[i,jj] <- 1
      }
      out[i,"expval"] <- in.vec[i]
   }

out
}


.gene.midas <- function(x, gene, group, base, thr=0.05,  probes.min=4, exonic=TRUE)
{
   ee <- exprs(x)
   pD <- pData(x)
   if (length(unique(pD[,group]))<=2) stop("Not enough \"",group,"\" variable levels in pData!")
   psets <- gene.to.probeset(gene, probes.min=probes.min)
   if (exonic) psets <- select.probewise(psets, filter="exonic")
   print(psets)
   out <- NULL
   out.desc <- NULL
   oo <- NULL

   #normalization
   ee <- ee[psets, ]
   ee <- apply (ee, 2, function(x) x/mean(x)) 

   for (p in psets)
   {
      pf <- .midas.pset.frame(ee,  p, pD,  group, base)
      print(pf)
      modelfrm <-  "expval ~ "
      for (i in 1:(length(colnames(pf))-2)) modelfrm <- paste(modelfrm, colnames(pf)[i],"+", sep="")
      modelfrm <- paste(modelfrm, colnames(pf)[length(colnames(pf))-1], sep="")
      tmp.mod <- lm(as.formula(modelfrm), data=pf)
      aa <- anova(tmp.mod)
      trtr <- rownames(aa)[which (aa["Pr(>F)"]<thr)]
      if (length(trtr)>0)
      {
        desc <- paste (p, trtr, sep="")
        out.desc <- c(out.desc, desc)
      }
      out <- rbind(out, aa[1:((dim(aa)[1]-1)),"Pr(>F)"])
   }
if (length(psets)>0)
{ 
rownames(out) <- psets
colnames(out) <- colnames(pf)[2:(length(colnames(pf))-1)]
}
else warning("Gene ",gene," has no well-behaved exonic probesets!")
out
oo$out <- out
oo$desc <- out.desc
oo
}
